
! Copyright (C) 2002-2005 J. K. Dewhurst, S. Sharma and C. Ambrosch-Draxl.
! This file is distributed under the terms of the GNU Lesser General Public
! License. See the file COPYING for license details.

!BOP
! !ROUTINE: rfmtctof
! !INTERFACE:
subroutine rfmtctof(rfmt)
! !INPUT/OUTPUT PARAMETERS:
!   rfmt : real muffin-tin function (in,real(lmmaxvr,nrmtmax,natmtot))
! !DESCRIPTION:
!   Converts a real muffin-tin function from a coarse to a fine radial mesh by
!   using cubic spline interpolation. See {\tt rfinterp} and {\tt spline}.
!
! !REVISION HISTORY:
!   Created October 2003 (JKD)
!EOP
!BOC
use modmain
implicit none
! arguments
real(8), intent(inout) :: rfmt(lmmaxvr,nrmtmax,natmtot)
! local variables
integer ld,is,ias,lm
integer nr,nri,nro,iro
integer nrc,nrci,nrco
if (lradstp.eq.1) return
ld=lmmaxvr*lradstp
!$OMP PARALLEL DEFAULT(SHARED) &
!$OMP PRIVATE(is,nr,nri,nro,iro) &
!$OMP PRIVATE(nrc,nrci,nrco,lm)
!$OMP DO
do ias=1,natmtot
  is=idxis(ias)
  nr=nrmt(is)-2
  nrc=nrcmt(is)
! interpolate up to lmaxinr over entire muffin-tin
  do lm=1,lmmaxinr
    call rfinterp(nrc,rcmt(1,is),ld,rfmt(lm,1,ias),nr,rsp(2,is),lmmaxvr, &
     rfmt(lm,2,ias))
  end do
! interpolate up to lmaxvr on outer part of muffin-tin
  nri=nrmtinr(is)
  nro=nrmt(is)-nri-1
  if (nro.le.0) cycle
  iro=nri+1
  nrci=nrcmtinr(is)
  nrco=nrc-nrci+1
  rfmt(lmmaxinr+1:lmmaxvr,nri,ias)=0.d0
  do lm=lmmaxinr+1,lmmaxvr
    call rfinterp(nrco,rcmt(nrci,is),ld,rfmt(lm,nri,ias),nro,rsp(iro,is), &
     lmmaxvr,rfmt(lm,iro,ias))
  end do
end do
!$OMP END DO
!$OMP END PARALLEL
return
end subroutine
!EOC

